@@ -1,7 +1,7 @@
-from .plot import plot, AnimatedAccessor, animate_multiple_plots
+from .plotting import plot, AnimatedAccessor, animate_multiple_plots
 from .base import load_dataset
 
-version = "0.1.8"
+version = "0.1.9"
 
 # Register animated_plot accessor for Pandas DataFrames and Series:
 import pandas as pd
